@@ -1,6 +1,6 @@
 package JavaScript::HashRef::Decode;
 {
-  $JavaScript::HashRef::Decode::VERSION = '0.130160';
+  $JavaScript::HashRef::Decode::VERSION = '0.130220';
 }
 
 ## ABSTRACT: JavaScript "simple object" (hashref) decoder
@@ -163,6 +163,8 @@ sub decode_js {
     $parser = Parse::RecDescent->new($js_grammar)
         if !defined $parser;
     my $parsed = $parser->hashref($str);
+    die "decode_js: Cannot parse (invalid js?) \"$str\""
+        if !defined $parsed;
     return $parsed->out;
 }
 
@@ -177,7 +179,7 @@ sub decode_js {
 
 package JavaScript::HashRef::Decode::NUMBER;
 {
-  $JavaScript::HashRef::Decode::NUMBER::VERSION = '0.130160';
+  $JavaScript::HashRef::Decode::NUMBER::VERSION = '0.130220';
 }
 
 sub out {
@@ -186,7 +188,7 @@ sub out {
 
 package JavaScript::HashRef::Decode::STRING;
 {
-  $JavaScript::HashRef::Decode::STRING::VERSION = '0.130160';
+  $JavaScript::HashRef::Decode::STRING::VERSION = '0.130220';
 }
 
 =item STRINGS
@@ -207,7 +209,7 @@ sub out {
 
 package JavaScript::HashRef::Decode::UNDEFINED;
 {
-  $JavaScript::HashRef::Decode::UNDEFINED::VERSION = '0.130160';
+  $JavaScript::HashRef::Decode::UNDEFINED::VERSION = '0.130220';
 }
 
 sub out {
@@ -216,7 +218,7 @@ sub out {
 
 package JavaScript::HashRef::Decode::TRUE;
 {
-  $JavaScript::HashRef::Decode::TRUE::VERSION = '0.130160';
+  $JavaScript::HashRef::Decode::TRUE::VERSION = '0.130220';
 }
 
 sub out {
@@ -225,7 +227,7 @@ sub out {
 
 package JavaScript::HashRef::Decode::FALSE;
 {
-  $JavaScript::HashRef::Decode::FALSE::VERSION = '0.130160';
+  $JavaScript::HashRef::Decode::FALSE::VERSION = '0.130220';
 }
 
 sub out {
@@ -234,7 +236,7 @@ sub out {
 
 package JavaScript::HashRef::Decode::ARRAYREF;
 {
-  $JavaScript::HashRef::Decode::ARRAYREF::VERSION = '0.130160';
+  $JavaScript::HashRef::Decode::ARRAYREF::VERSION = '0.130220';
 }
 
 sub out {
@@ -243,7 +245,7 @@ sub out {
 
 package JavaScript::HashRef::Decode::KEY;
 {
-  $JavaScript::HashRef::Decode::KEY::VERSION = '0.130160';
+  $JavaScript::HashRef::Decode::KEY::VERSION = '0.130220';
 }
 
 sub out {
@@ -252,7 +254,7 @@ sub out {
 
 package JavaScript::HashRef::Decode::TUPLE;
 {
-  $JavaScript::HashRef::Decode::TUPLE::VERSION = '0.130160';
+  $JavaScript::HashRef::Decode::TUPLE::VERSION = '0.130220';
 }
 
 sub out {
@@ -261,7 +263,7 @@ sub out {
 
 package JavaScript::HashRef::Decode::HASHREF;
 {
-  $JavaScript::HashRef::Decode::HASHREF::VERSION = '0.130160';
+  $JavaScript::HashRef::Decode::HASHREF::VERSION = '0.130220';
 }
 
 sub out {
@@ -274,7 +276,7 @@ sub out {
 
 L<Parse::RecDescent>
 
-The ECMAScript Object specification.
+The ECMAScript Object specification: L<http://www.ecmascript.org/>
 
 =head1 AUTHOR
 
